@@ -43,17 +43,17 @@
 #ifdef _WIN32
 #define close closesocket
 #else
-#include <sys/types.h>        /*  socket types              */
-#include <sys/socket.h>       /*  socket definitions        */
+#include <sys/types.h>   /* socket types */
+#include <sys/socket.h>  /* socket definitions */
 #include <netinet/in.h>
-#include <arpa/inet.h>        /*  inet (3) functions        */
-#include <unistd.h>           /*  misc. Unix functions      */
+#include <arpa/inet.h>   /* inet (3) functions */
+#include <unistd.h>      /* misc. Unix functions */
 #endif
 
 #include <errno.h>
 
 /* The IP address and port number to connect to */
-#define IPADDR "127.0.0.1"
+#define IPADDR  "127.0.0.1"
 #define PORTNUM 80
 
 #ifndef INADDR_NONE
@@ -99,13 +99,13 @@ static int sockopt_callback(void *clientp, curl_socket_t curlfd,
 int main(void)
 {
   CURL *curl;
-  CURLcode res;
+  CURLcode result;
   struct sockaddr_in servaddr;  /*  socket address structure  */
   curl_socket_t sockfd;
 
-  res = curl_global_init(CURL_GLOBAL_ALL);
-  if(res)
-    return (int)res;
+  result = curl_global_init(CURL_GLOBAL_ALL);
+  if(result != CURLE_OK)
+    return (int)result;
 
   curl = curl_easy_init();
   if(curl) {
@@ -124,7 +124,7 @@ int main(void)
 
     memset(&servaddr, 0, sizeof(servaddr));
     servaddr.sin_family = AF_INET;
-    servaddr.sin_port   = htons(PORTNUM);
+    servaddr.sin_port = htons(PORTNUM);
 
     servaddr.sin_addr.s_addr = inet_addr(IPADDR);
     if(INADDR_NONE == servaddr.sin_addr.s_addr) {
@@ -132,8 +132,7 @@ int main(void)
       return 2;
     }
 
-    if(connect(sockfd, (struct sockaddr *) &servaddr, sizeof(servaddr)) ==
-       -1) {
+    if(connect(sockfd, (struct sockaddr *)&servaddr, sizeof(servaddr)) == -1) {
       close(sockfd);
       printf("client error: connect: %s\n", strerror(errno));
       return 1;
@@ -158,14 +157,14 @@ int main(void)
 
     curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
 
-    res = curl_easy_perform(curl);
+    result = curl_easy_perform(curl);
 
     curl_easy_cleanup(curl);
 
     close(sockfd);
 
-    if(res) {
-      printf("libcurl error: %d\n", res);
+    if(result != CURLE_OK) {
+      printf("libcurl error: %d\n", result);
       return 4;
     }
   }
